# Generated by Django 3.1.4 on 2020-12-22 17:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aasrp", "0008_auto_20201123_1322"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrprequestcomment",
            name="comment_type",
            field=models.CharField(
                choices=[
                    ("Comment", "SRP Request Comment"),
                    ("Request Information", "SRP Request Additional Information"),
                    ("Reject Reason", "SRP Reject Reason"),
                ],
                default="Comment",
                max_length=19,
            ),
        ),
    ]
