# Generated by Django 3.1.3 on 2020-11-09 17:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("eveonline", "0012_index_additions"),
        ("aasrp", "0005_auto_20201109_1708"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrprequest",
            name="character",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="eveonline.evecharacter",
            ),
        ),
    ]
