# Generated by Django 3.1.3 on 2020-11-06 12:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aasrp", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrplink",
            name="srp_code",
            field=models.CharField(default="", max_length=16),
        ),
        migrations.AlterField(
            model_name="aasrplink",
            name="srp_status",
            field=models.CharField(
                choices=[
                    ("Active", "Active"),
                    ("Closed", "Closed"),
                    ("Completed", "Completed"),
                ],
                default="Active",
                max_length=9,
            ),
        ),
    ]
