{% load i18n %}
{% load humanize %}

<div class="panel panel-default">
    <div class="panel-heading">
        <div class="panel-title">
            {% translate "SRP Requests" %}
        </div>
    </div>

    <div class="panel-body">
        <table class="table table-striped table-aasrp table-pending-srp-requests" id="tab_aasrp_srp_requests" style="width: 100%;">
            <thead>
                <tr>
                    <th>{% translate "Request Time" %}</th>
                    <th>{% translate "Requestor" %}</th>
                    <th>{% translate "Character" %}</th>
                    <th>{% translate "Request Code" %}</th>
                    <th>{% translate "Ship" %}</th>
{#                    <th>{% translate "Killmail" %}</th>#}
                    <th>{% translate "ISK Lost" %}</th>
                    <th>{% translate "SRP Payout" %}</th>
                    <th>{% translate "Status" %}</th>
                    <th>{% translate "Actions" %}</th>
                </tr>
            </thead>
            <tbody></tbody>
        </table>
    </div>
</div>
