# Generated by Django 3.1.3 on 2020-11-23 10:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aasrp", "0006_auto_20201109_1747"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aasrplink",
            name="aar_link",
            field=models.CharField(blank=True, default="", max_length=254),
        ),
    ]
