# Generated by Django 3.1.3 on 2020-11-09 17:07

import aasrp.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("aasrp", "0003_auto_20201109_1654"),
    ]

    operations = [
        migrations.AddField(
            model_name="aasrplink",
            name="creator",
            field=models.ForeignKey(
                help_text="Who created the SRP link?",
                null=True,
                on_delete=models.SET(aasrp.models.get_sentinel_user),
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
